@@ -524,6 +524,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   MagickOffsetType
     offset,
+    profile_data,
+    profile_size,
     start_position;
 
   MemoryInfo
@@ -628,6 +630,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (image->debug != MagickFalse)
       (void) LogMagickEvent(CoderEvent,GetMagickModule(),"  BMP size: %u",
         bmp_info.size);
+    profile_data=0;
+    profile_size=0;
     if (bmp_info.size == 12)
       {
         /*
@@ -826,8 +830,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               }
             }
-            (void) ReadBlobLSBLong(image);  /* Profile data */
-            (void) ReadBlobLSBLong(image);  /* Profile size */
+            profile_data=(MagickOffsetType) ReadBlobLSBLong(image);
+            profile_size=(MagickOffsetType) ReadBlobLSBLong(image);
             (void) ReadBlobLSBLong(image);  /* Reserved byte */
           }
       }
@@ -1448,6 +1452,48 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             image=flipped_image;
           }
       }
+    /*
+      Read embeded ICC profile
+    */
+    if ((bmp_info.colorspace == 0x4D424544L) && (profile_data > 0) &&
+        (profile_size > 0))
+      {
+        StringInfo
+          *profile;
+
+        unsigned char
+          *datum;
+
+        offset=start_position+14+profile_data;
+        if ((offset < TellBlob(image)) ||
+            (SeekBlob(image,offset,SEEK_SET) != offset) ||
+            (GetBlobSize(image) < (MagickSizeType) (offset+profile_size)))
+          ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+        profile=AcquireStringInfo((size_t) profile_size);
+        if (profile == (StringInfo *) NULL)
+          ThrowReaderException(CorruptImageError,"MemoryAllocationFailed");
+        datum=GetStringInfoDatum(profile);
+        if (ReadBlob(image,(size_t) profile_size,datum) == (ssize_t) profile_size)
+          {
+            MagickOffsetType
+              profile_size_orig;
+
+            /*
+             Trimming padded bytes.
+            */
+            profile_size_orig=(MagickOffsetType) datum[0] << 24;
+            profile_size_orig|=(MagickOffsetType) datum[1] << 16;
+            profile_size_orig|=(MagickOffsetType) datum[2] << 8;
+            profile_size_orig|=(MagickOffsetType) datum[3];
+            if (profile_size_orig < profile_size)
+              SetStringInfoLength(profile,(size_t) profile_size_orig);
+            if (image->debug != MagickFalse)
+              (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                "Profile: ICC, %u bytes",(unsigned int) profile_size_orig);
+            (void) SetImageProfile(image,"icc",profile);
+          }
+        profile=DestroyStringInfo(profile);
+      }
     /*
       Proceed to next image.
     */
@@ -1661,6 +1707,9 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
+  if (((image->columns << 3) != (int) (image->columns << 3)) ||
+      ((image->rows << 3) != (int) (image->rows << 3)))
+    ThrowWriterException(ImageError,"WidthOrHeightExceedsLimit");
   type=4;
   if (LocaleCompare(image_info->magick,"BMP2") == 0)
     type=2;
