@@ -118,6 +118,9 @@ static SemaphoreInfo
 
 static WSADATA
   *wsaData = (WSADATA*) NULL;
+
+static size_t
+  long_paths_enabled = 2;
 
 struct
 {
@@ -1449,6 +1452,10 @@ MagickPrivate int NTGhostscriptFonts(char *path,int length)
       DirectorySeparator);
     if (IsPathAccessible(filename) != MagickFalse)
       return(TRUE);
+    (void) FormatLocaleString(filename,MaxTextExtent,"%s%sn019003l.pfb",path,
+      DirectorySeparator);
+    if (IsPathAccessible(filename) != MagickFalse)
+      return(TRUE);
   }
   *path='\0';
   return(FALSE);
@@ -1638,6 +1645,72 @@ MagickPrivate void NTInitializeWinsock(MagickBooleanType use_lock)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   N T L o n g P a t h s E n a b l e d                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  NTLongPathsEnabled() returns a boolean indicating whether long paths are
+$  enabled.
+%
+%  The format of the NTLongPathsEnabled method is:
+%
+%      MagickBooleanType NTLongPathsEnabled()
+%
+*/
+MagickExport MagickBooleanType NTLongPathsEnabled()
+{
+  if (long_paths_enabled == 2)
+    {
+      DWORD
+        size,
+        type,
+        value;
+
+      HKEY
+        registry_key;
+
+      LONG
+        status;
+
+      registry_key=(HKEY) INVALID_HANDLE_VALUE;
+      status=RegOpenKeyExA(HKEY_LOCAL_MACHINE,
+        "SYSTEM\\CurrentControlSet\\Control\\FileSystem",0,KEY_READ,
+        &registry_key);
+      if (status != ERROR_SUCCESS)
+      {
+        long_paths_enabled=0;
+        RegCloseKey(registry_key);
+        return(MagickFalse);
+      }
+      value=(PVOID) NULL;
+      status=RegQueryValueExA(registry_key,"LongPathsEnabled",0,&type,NULL,
+        NULL);
+      if ((status != ERROR_SUCCESS) || (type != REG_DWORD))
+      {
+        long_paths_enabled=0;
+        RegCloseKey(registry_key);
+        return(MagickFalse);
+      }
+      status=RegQueryValueExA(registry_key,"LongPathsEnabled",0,&type,&value,
+        &size);
+      RegCloseKey(registry_key);
+      if (status != ERROR_SUCCESS)
+      {
+        long_paths_enabled=0;
+        return(MagickFalse);
+      }
+      long_paths_enabled=(size_t)value;
+    }
+  return(long_paths_enabled == 1 ? MagickTrue : MagickFalse);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +  N T M a p M e m o r y                                                      %
 %                                                                             %
 %                                                                             %
